summaryrefslogtreecommitdiff
path: root/hints
diff options
context:
space:
mode:
authorChip Salzenberg <chip@perl.com>1997-05-09 03:03:58 +1200
committerChip Salzenberg <chip@atlantic.net>1997-05-16 10:15:00 +1200
commitba51d756f9ffaa3939ada6861397f27ce3967220 (patch)
tree1d5e383c56dffa5f2a859fbe0638dcea874cf631 /hints
parent4aad70739bb5667e0ca185adfc2a6357768d5434 (diff)
downloadperl-ba51d756f9ffaa3939ada6861397f27ce3967220.tar.gz
Make Irix hints adapt when n32 libm.so is missing
Diffstat (limited to 'hints')
-rw-r--r--hints/irix_6.sh30
1 files changed, 18 insertions, 12 deletions
diff --git a/hints/irix_6.sh b/hints/irix_6.sh
index a541fcff3f..060d972748 100644
--- a/hints/irix_6.sh
+++ b/hints/irix_6.sh
@@ -2,31 +2,37 @@
#
# original from Krishna Sethuraman, krishna@sgi.com
#
-# Updated Mon Jul 22 14:52:25 EDT 1996
+# Modified Mon Jul 22 14:52:25 EDT 1996
# Andy Dougherty <doughera@lafcol.lafayette.edu>
# with help from Dean Roehrich <roehrich@cray.com>.
# cc -n32 update info from Krishna Sethuraman, krishna@sgi.com.
# additional update from Scott Henry, scotth@sgi.com
-# Futzed with by John Stoffel <jfs@fluent.com> on 4/24/1997
-# - assumes 'cc -n32' by default
-# - tries to check for various compiler versions and do the right
-# thing when it can
-# - warnings turned off (-n32 messages):
-# 1116 - non-void function should return a value
-# 1048 - cast between pointer-to-object and pointer-to-function
-# 1042 - operand types are incompatible
+# Futzed with by John Stoffel <jfs@fluent.com> on 4/24/1997
+# - assumes 'cc -n32' by default
+# - tries to check for various compiler versions and do the right
+# thing when it can
+# - warnings turned off (-n32 messages):
+# 1116 - non-void function should return a value
+# 1048 - cast between pointer-to-object and pointer-to-function
+# 1042 - operand types are incompatible
+
+# Tweaked by Chip Salzenberg <chip@perl.com> on 5/13/97
+# - don't assume 'cc -n32' if the n32 libm.so is missing
# Use sh Configure -Dcc='cc -n32' to try compiling with -n32.
# or -Dcc='cc -n32 -mips3' (or -mips4) to force (non)portability
# Don't bother with -n32 unless you have the 7.1 or later compilers.
# But there's no quick and light-weight way to check in 6.2.
-# Let's assume we want to use 'cc -n32' by default
+# Let's assume we want to use 'cc -n32' by default, unless the
+# necessary libm is missing (which has happened at least twice)
case "$cc" in
'')
- cc='cc -n32'
- ;;
+ if test -f /usr/lib32/libm.so
+ then
+ cc='cc -n32'
+ fi ;;
esac
# Check for which compiler we're using